@@ -28,7 +28,7 @@ Here is a minimal deployable pattern definition:
 
 Typescript
 
-```typescript
+```python
 import { Construct } from 'constructs';
 import { Stack, StackProps } from 'aws-cdk-lib';
 import { LambdaToSqs, LambdaToSqsProps } from "@aws-solutions-constructs/aws-lambda-sqs";
@@ -149,6 +149,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -171,18 +173,18 @@ class LambdaToSqs(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
         enable_queue_purging: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_environment_variable_name: typing.Optional[builtins.str] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -204,6 +206,10 @@ class LambdaToSqs(
         :since: 1.49.0
         :summary: Constructs a new instance of the LambdaToSqs class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaToSqs.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToSqsProps(
             dead_letter_queue_props=dead_letter_queue_props,
             deploy_dead_letter_queue=deploy_dead_letter_queue,
@@ -264,18 +270,18 @@ class LambdaToSqsProps:
     def __init__(
         self,
         *,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
         enable_queue_purging: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_environment_variable_name: typing.Optional[builtins.str] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
@@ -301,6 +307,20 @@ class LambdaToSqsProps:
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaToSqsProps.__init__)
+            check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
+            check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
+            check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
+            check_type(argname="argument enable_queue_purging", value=enable_queue_purging, expected_type=type_hints["enable_queue_purging"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
+            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
+            check_type(argname="argument queue_environment_variable_name", value=queue_environment_variable_name, expected_type=type_hints["queue_environment_variable_name"])
+            check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
+            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue_props is not None:
             self._values["dead_letter_queue_props"] = dead_letter_queue_props
